pub struct CustodianStudyAccessRequestApproval {
pub datastore_id: AccessRequestDatastoreId,
pub request_id: AccessRequestId,
pub requester_role: String,
}Expand description
Input for a custodian’s governed approval of a Study access request.
requester_role is the datastore workflow role provisioned by the caller
after a successful pending-request inspection.
Fields
datastore_id: AccessRequestDatastoreIdrequest_id: AccessRequestIdrequester_role: StringTrait Implementations
Sourceimpl Clone for CustodianStudyAccessRequestApproval
impl Clone for CustodianStudyAccessRequestApproval
Sourcefn clone(&self) -> CustodianStudyAccessRequestApproval
fn clone(&self) -> CustodianStudyAccessRequestApproval
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CustodianStudyAccessRequestApproval
impl PartialEq for CustodianStudyAccessRequestApproval
Sourcefn eq(&self, other: &CustodianStudyAccessRequestApproval) -> bool
fn eq(&self, other: &CustodianStudyAccessRequestApproval) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CustodianStudyAccessRequestApproval
impl StructuralPartialEq for CustodianStudyAccessRequestApproval