pub struct CustodianStudyAccessRequestScope {
pub datastore_id: AccessRequestDatastoreId,
pub request_id: AccessRequestId,
}Expand description
Scope used by a custodian inspection of a Study access request.
Fields
datastore_id: AccessRequestDatastoreIdrequest_id: AccessRequestIdTrait Implementations
Sourceimpl Clone for CustodianStudyAccessRequestScope
impl Clone for CustodianStudyAccessRequestScope
Sourcefn clone(&self) -> CustodianStudyAccessRequestScope
fn clone(&self) -> CustodianStudyAccessRequestScope
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CustodianStudyAccessRequestScope
impl PartialEq for CustodianStudyAccessRequestScope
Sourcefn eq(&self, other: &CustodianStudyAccessRequestScope) -> bool
fn eq(&self, other: &CustodianStudyAccessRequestScope) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CustodianStudyAccessRequestScope
impl StructuralPartialEq for CustodianStudyAccessRequestScope