scoped_evidence_ids

Function scoped_evidence_ids 

pub fn scoped_evidence_ids<E: MetadataExecutor>(
    db: &mut E,
    study: Uuid,
    after: DateTime<Utc>,
    after_id: Uuid,
    limit: u32,
) -> Result<Vec<Uuid>, PgMetaError>
where E::Row: SchemaStatusRow,
Current owning-Study custodians and the appointed governance custodian may discover only acknowledged event identities through the ordinary Session.